# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class MediaUpdate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'attributes': 'dict(str, AttributeValue)',
        'last_edit_end': 'datetime',
        'last_edit_start': 'datetime',
        'media_files': 'list[str]',
        'name': 'str'
    }

    attribute_map = {
        'attributes': 'attributes',
        'last_edit_end': 'last_edit_end',
        'last_edit_start': 'last_edit_start',
        'media_files': 'media_files',
        'name': 'name'
    }

    def __init__(self, attributes=None, last_edit_end=None, last_edit_start=None, media_files=None, name=None):  # noqa: E501
        """MediaUpdate - a model defined in Swagger"""  # noqa: E501
        self._attributes = None
        self._last_edit_end = None
        self._last_edit_start = None
        self._media_files = None
        self._name = None
        self.discriminator = None
        if attributes is not None:
            self.attributes = attributes
        if last_edit_end is not None:
            self.last_edit_end = last_edit_end
        if last_edit_start is not None:
            self.last_edit_start = last_edit_start
        if media_files is not None:
            self.media_files = media_files
        if name is not None:
            self.name = name

    @property
    def attributes(self):
        """Gets the attributes of this MediaUpdate.  # noqa: E501

        Object containing attribute values.  # noqa: E501

        :return: The attributes of this MediaUpdate.  # noqa: E501
        :rtype: dict(str, AttributeValue)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this MediaUpdate.

        Object containing attribute values.  # noqa: E501

        :param attributes: The attributes of this MediaUpdate.  # noqa: E501
        :type: dict(str, AttributeValue)
        """

        self._attributes = attributes

    @property
    def last_edit_end(self):
        """Gets the last_edit_end of this MediaUpdate.  # noqa: E501

        Datetime of the end of the session when this media or its annotations were last edited.  # noqa: E501

        :return: The last_edit_end of this MediaUpdate.  # noqa: E501
        :rtype: datetime
        """
        return self._last_edit_end

    @last_edit_end.setter
    def last_edit_end(self, last_edit_end):
        """Sets the last_edit_end of this MediaUpdate.

        Datetime of the end of the session when this media or its annotations were last edited.  # noqa: E501

        :param last_edit_end: The last_edit_end of this MediaUpdate.  # noqa: E501
        :type: datetime
        """

        self._last_edit_end = last_edit_end

    @property
    def last_edit_start(self):
        """Gets the last_edit_start of this MediaUpdate.  # noqa: E501

        Datetime of the start of the session when this media or its annotations were last edited.  # noqa: E501

        :return: The last_edit_start of this MediaUpdate.  # noqa: E501
        :rtype: datetime
        """
        return self._last_edit_start

    @last_edit_start.setter
    def last_edit_start(self, last_edit_start):
        """Sets the last_edit_start of this MediaUpdate.

        Datetime of the start of the session when this media or its annotations were last edited.  # noqa: E501

        :param last_edit_start: The last_edit_start of this MediaUpdate.  # noqa: E501
        :type: datetime
        """

        self._last_edit_start = last_edit_start

    @property
    def media_files(self):
        """Gets the media_files of this MediaUpdate.  # noqa: E501

        Object containing upload urls for the transcoded file and corresponding `VideoDefinition`.  # noqa: E501

        :return: The media_files of this MediaUpdate.  # noqa: E501
        :rtype: list[str]
        """
        return self._media_files

    @media_files.setter
    def media_files(self, media_files):
        """Sets the media_files of this MediaUpdate.

        Object containing upload urls for the transcoded file and corresponding `VideoDefinition`.  # noqa: E501

        :param media_files: The media_files of this MediaUpdate.  # noqa: E501
        :type: list[str]
        """

        self._media_files = media_files

    @property
    def name(self):
        """Gets the name of this MediaUpdate.  # noqa: E501

        Name of the media.  # noqa: E501

        :return: The name of this MediaUpdate.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MediaUpdate.

        Name of the media.  # noqa: E501

        :param name: The name of this MediaUpdate.  # noqa: E501
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MediaUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MediaUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Version(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bases': 'list[int]',
        'created_by': 'str',
        'created_datetime': 'str',
        'description': 'str',
        'id': 'int',
        'modified_by': 'str',
        'modified_datetime': 'str',
        'name': 'str',
        'num_created': 'int',
        'num_modified': 'int',
        'number': 'int',
        'project': 'int',
        'show_empty': 'bool'
    }

    attribute_map = {
        'bases': 'bases',
        'created_by': 'created_by',
        'created_datetime': 'created_datetime',
        'description': 'description',
        'id': 'id',
        'modified_by': 'modified_by',
        'modified_datetime': 'modified_datetime',
        'name': 'name',
        'num_created': 'num_created',
        'num_modified': 'num_modified',
        'number': 'number',
        'project': 'project',
        'show_empty': 'show_empty'
    }

    def __init__(self, bases=None, created_by=None, created_datetime=None, description='', id=None, modified_by=None, modified_datetime=None, name=None, num_created=None, num_modified=None, number=None, project=None, show_empty=True):  # noqa: E501
        """Version - a model defined in Swagger"""  # noqa: E501
        self._bases = None
        self._created_by = None
        self._created_datetime = None
        self._description = None
        self._id = None
        self._modified_by = None
        self._modified_datetime = None
        self._name = None
        self._num_created = None
        self._num_modified = None
        self._number = None
        self._project = None
        self._show_empty = None
        self.discriminator = None
        if bases is not None:
            self.bases = bases
        if created_by is not None:
            self.created_by = created_by
        if created_datetime is not None:
            self.created_datetime = created_datetime
        if description is not None:
            self.description = description
        if id is not None:
            self.id = id
        if modified_by is not None:
            self.modified_by = modified_by
        if modified_datetime is not None:
            self.modified_datetime = modified_datetime
        if name is not None:
            self.name = name
        if num_created is not None:
            self.num_created = num_created
        if num_modified is not None:
            self.num_modified = num_modified
        if number is not None:
            self.number = number
        if project is not None:
            self.project = project
        if show_empty is not None:
            self.show_empty = show_empty

    @property
    def bases(self):
        """Gets the bases of this Version.  # noqa: E501

        Array of other version IDs that are dependencies of this version.  # noqa: E501

        :return: The bases of this Version.  # noqa: E501
        :rtype: list[int]
        """
        return self._bases

    @bases.setter
    def bases(self, bases):
        """Sets the bases of this Version.

        Array of other version IDs that are dependencies of this version.  # noqa: E501

        :param bases: The bases of this Version.  # noqa: E501
        :type: list[int]
        """

        self._bases = bases

    @property
    def created_by(self):
        """Gets the created_by of this Version.  # noqa: E501

        Name of user who created the last unmodified annotation in this version.  # noqa: E501

        :return: The created_by of this Version.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this Version.

        Name of user who created the last unmodified annotation in this version.  # noqa: E501

        :param created_by: The created_by of this Version.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def created_datetime(self):
        """Gets the created_datetime of this Version.  # noqa: E501

        Datetime when the last unmodified annotation was created.  # noqa: E501

        :return: The created_datetime of this Version.  # noqa: E501
        :rtype: str
        """
        return self._created_datetime

    @created_datetime.setter
    def created_datetime(self, created_datetime):
        """Sets the created_datetime of this Version.

        Datetime when the last unmodified annotation was created.  # noqa: E501

        :param created_datetime: The created_datetime of this Version.  # noqa: E501
        :type: str
        """

        self._created_datetime = created_datetime

    @property
    def description(self):
        """Gets the description of this Version.  # noqa: E501

        Description of the version.  # noqa: E501

        :return: The description of this Version.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Version.

        Description of the version.  # noqa: E501

        :param description: The description of this Version.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """Gets the id of this Version.  # noqa: E501

        Unique integer identifying a membership.  # noqa: E501

        :return: The id of this Version.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Version.

        Unique integer identifying a membership.  # noqa: E501

        :param id: The id of this Version.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def modified_by(self):
        """Gets the modified_by of this Version.  # noqa: E501

        Name of user who modified annotations in this version most recently.  # noqa: E501

        :return: The modified_by of this Version.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this Version.

        Name of user who modified annotations in this version most recently.  # noqa: E501

        :param modified_by: The modified_by of this Version.  # noqa: E501
        :type: str
        """

        self._modified_by = modified_by

    @property
    def modified_datetime(self):
        """Gets the modified_datetime of this Version.  # noqa: E501

        Datetime when last annotation was modified in the web interface.  # noqa: E501

        :return: The modified_datetime of this Version.  # noqa: E501
        :rtype: str
        """
        return self._modified_datetime

    @modified_datetime.setter
    def modified_datetime(self, modified_datetime):
        """Sets the modified_datetime of this Version.

        Datetime when last annotation was modified in the web interface.  # noqa: E501

        :param modified_datetime: The modified_datetime of this Version.  # noqa: E501
        :type: str
        """

        self._modified_datetime = modified_datetime

    @property
    def name(self):
        """Gets the name of this Version.  # noqa: E501

        Name of the version.  # noqa: E501

        :return: The name of this Version.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Version.

        Name of the version.  # noqa: E501

        :param name: The name of this Version.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def num_created(self):
        """Gets the num_created of this Version.  # noqa: E501

        Number of created annotations in this version.  # noqa: E501

        :return: The num_created of this Version.  # noqa: E501
        :rtype: int
        """
        return self._num_created

    @num_created.setter
    def num_created(self, num_created):
        """Sets the num_created of this Version.

        Number of created annotations in this version.  # noqa: E501

        :param num_created: The num_created of this Version.  # noqa: E501
        :type: int
        """

        self._num_created = num_created

    @property
    def num_modified(self):
        """Gets the num_modified of this Version.  # noqa: E501

        Number of modified annotations in this version.  # noqa: E501

        :return: The num_modified of this Version.  # noqa: E501
        :rtype: int
        """
        return self._num_modified

    @num_modified.setter
    def num_modified(self, num_modified):
        """Sets the num_modified of this Version.

        Number of modified annotations in this version.  # noqa: E501

        :param num_modified: The num_modified of this Version.  # noqa: E501
        :type: int
        """

        self._num_modified = num_modified

    @property
    def number(self):
        """Gets the number of this Version.  # noqa: E501

        Version number.  # noqa: E501

        :return: The number of this Version.  # noqa: E501
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this Version.

        Version number.  # noqa: E501

        :param number: The number of this Version.  # noqa: E501
        :type: int
        """

        self._number = number

    @property
    def project(self):
        """Gets the project of this Version.  # noqa: E501

        Unique integer identifying a project.  # noqa: E501

        :return: The project of this Version.  # noqa: E501
        :rtype: int
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this Version.

        Unique integer identifying a project.  # noqa: E501

        :param project: The project of this Version.  # noqa: E501
        :type: int
        """

        self._project = project

    @property
    def show_empty(self):
        """Gets the show_empty of this Version.  # noqa: E501

        Whether to show this version on media for which no annotations exist.  # noqa: E501

        :return: The show_empty of this Version.  # noqa: E501
        :rtype: bool
        """
        return self._show_empty

    @show_empty.setter
    def show_empty(self, show_empty):
        """Sets the show_empty of this Version.

        Whether to show this version on media for which no annotations exist.  # noqa: E501

        :param show_empty: The show_empty of this Version.  # noqa: E501
        :type: bool
        """

        self._show_empty = show_empty

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Version, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Version):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class VideoUpdate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gid': 'str',
        'id': 'int',
        'media_files': 'list[str]',
        'uid': 'str'
    }

    attribute_map = {
        'gid': 'gid',
        'id': 'id',
        'media_files': 'media_files',
        'uid': 'uid'
    }

    def __init__(self, gid=None, id=None, media_files=None, uid=None):  # noqa: E501
        """VideoUpdate - a model defined in Swagger"""  # noqa: E501
        self._gid = None
        self._id = None
        self._media_files = None
        self._uid = None
        self.discriminator = None
        self.gid = gid
        self.id = id
        self.media_files = media_files
        self.uid = uid

    @property
    def gid(self):
        """Gets the gid of this VideoUpdate.  # noqa: E501

        UUID generated for the job group. This value is returned in the response of the `AlgorithmLaunch` and `Transcode` endpoints.  # noqa: E501

        :return: The gid of this VideoUpdate.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this VideoUpdate.

        UUID generated for the job group. This value is returned in the response of the `AlgorithmLaunch` and `Transcode` endpoints.  # noqa: E501

        :param gid: The gid of this VideoUpdate.  # noqa: E501
        :type: str
        """
        if gid is None:
            raise ValueError("Invalid value for `gid`, must not be `None`")  # noqa: E501

        self._gid = gid

    @property
    def id(self):
        """Gets the id of this VideoUpdate.  # noqa: E501

        Unique integer identifying a media.  # noqa: E501

        :return: The id of this VideoUpdate.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this VideoUpdate.

        Unique integer identifying a media.  # noqa: E501

        :param id: The id of this VideoUpdate.  # noqa: E501
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def media_files(self):
        """Gets the media_files of this VideoUpdate.  # noqa: E501

        Object containing upload urls for the transcoded file and corresponding `VideoDefinition`.  # noqa: E501

        :return: The media_files of this VideoUpdate.  # noqa: E501
        :rtype: list[str]
        """
        return self._media_files

    @media_files.setter
    def media_files(self, media_files):
        """Sets the media_files of this VideoUpdate.

        Object containing upload urls for the transcoded file and corresponding `VideoDefinition`.  # noqa: E501

        :param media_files: The media_files of this VideoUpdate.  # noqa: E501
        :type: list[str]
        """
        if media_files is None:
            raise ValueError("Invalid value for `media_files`, must not be `None`")  # noqa: E501

        self._media_files = media_files

    @property
    def uid(self):
        """Gets the uid of this VideoUpdate.  # noqa: E501

        UUID generated for the individual job. This value is returned in the response of the `AlgorithmLaunch` and `Transcode` endpoints.  # noqa: E501

        :return: The uid of this VideoUpdate.  # noqa: E501
        :rtype: str
        """
        return self._uid

    @uid.setter
    def uid(self, uid):
        """Sets the uid of this VideoUpdate.

        UUID generated for the individual job. This value is returned in the response of the `AlgorithmLaunch` and `Transcode` endpoints.  # noqa: E501

        :param uid: The uid of this VideoUpdate.  # noqa: E501
        :type: str
        """
        if uid is None:
            raise ValueError("Invalid value for `uid`, must not be `None`")  # noqa: E501

        self._uid = uid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VideoUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VideoUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class MediaTypeUpdate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'file_format': 'str',
        'keep_original': 'bool',
        'name': 'str'
    }

    attribute_map = {
        'description': 'description',
        'file_format': 'file_format',
        'keep_original': 'keep_original',
        'name': 'name'
    }

    def __init__(self, description='', file_format=None, keep_original=True, name=None):  # noqa: E501
        """MediaTypeUpdate - a model defined in Swagger"""  # noqa: E501
        self._description = None
        self._file_format = None
        self._keep_original = None
        self._name = None
        self.discriminator = None
        if description is not None:
            self.description = description
        if file_format is not None:
            self.file_format = file_format
        if keep_original is not None:
            self.keep_original = keep_original
        if name is not None:
            self.name = name

    @property
    def description(self):
        """Gets the description of this MediaTypeUpdate.  # noqa: E501

        Description of the media type.  # noqa: E501

        :return: The description of this MediaTypeUpdate.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this MediaTypeUpdate.

        Description of the media type.  # noqa: E501

        :param description: The description of this MediaTypeUpdate.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def file_format(self):
        """Gets the file_format of this MediaTypeUpdate.  # noqa: E501

        File extension. If omitted, any recognized file extension for the given dtype is accepted for upload. Do not include a dot prefix.  # noqa: E501

        :return: The file_format of this MediaTypeUpdate.  # noqa: E501
        :rtype: str
        """
        return self._file_format

    @file_format.setter
    def file_format(self, file_format):
        """Sets the file_format of this MediaTypeUpdate.

        File extension. If omitted, any recognized file extension for the given dtype is accepted for upload. Do not include a dot prefix.  # noqa: E501

        :param file_format: The file_format of this MediaTypeUpdate.  # noqa: E501
        :type: str
        """

        self._file_format = file_format

    @property
    def keep_original(self):
        """Gets the keep_original of this MediaTypeUpdate.  # noqa: E501

        For video dtype, whether to keep the original video file for archival purposes after transcoding. If true, the originally uploaded file will be available for download, otherwise downloads will use the transcoded videos.  # noqa: E501

        :return: The keep_original of this MediaTypeUpdate.  # noqa: E501
        :rtype: bool
        """
        return self._keep_original

    @keep_original.setter
    def keep_original(self, keep_original):
        """Sets the keep_original of this MediaTypeUpdate.

        For video dtype, whether to keep the original video file for archival purposes after transcoding. If true, the originally uploaded file will be available for download, otherwise downloads will use the transcoded videos.  # noqa: E501

        :param keep_original: The keep_original of this MediaTypeUpdate.  # noqa: E501
        :type: bool
        """

        self._keep_original = keep_original

    @property
    def name(self):
        """Gets the name of this MediaTypeUpdate.  # noqa: E501

        Name of the media type.  # noqa: E501

        :return: The name of this MediaTypeUpdate.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MediaTypeUpdate.

        Name of the media type.  # noqa: E501

        :param name: The name of this MediaTypeUpdate.  # noqa: E501
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MediaTypeUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MediaTypeUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TemporaryFile(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_datetime': 'str',
        'eol_datetime': 'str',
        'id': 'int',
        'lookup': 'str',
        'name': 'str',
        'path': 'str',
        'project': 'int',
        'user': 'int'
    }

    attribute_map = {
        'created_datetime': 'created_datetime',
        'eol_datetime': 'eol_datetime',
        'id': 'id',
        'lookup': 'lookup',
        'name': 'name',
        'path': 'path',
        'project': 'project',
        'user': 'user'
    }

    def __init__(self, created_datetime=None, eol_datetime=None, id=None, lookup=None, name=None, path=None, project=None, user=None):  # noqa: E501
        """TemporaryFile - a model defined in Swagger"""  # noqa: E501
        self._created_datetime = None
        self._eol_datetime = None
        self._id = None
        self._lookup = None
        self._name = None
        self._path = None
        self._project = None
        self._user = None
        self.discriminator = None
        if created_datetime is not None:
            self.created_datetime = created_datetime
        if eol_datetime is not None:
            self.eol_datetime = eol_datetime
        if id is not None:
            self.id = id
        if lookup is not None:
            self.lookup = lookup
        if name is not None:
            self.name = name
        if path is not None:
            self.path = path
        if project is not None:
            self.project = project
        if user is not None:
            self.user = user

    @property
    def created_datetime(self):
        """Gets the created_datetime of this TemporaryFile.  # noqa: E501

        Datetime when this temporary file was created.  # noqa: E501

        :return: The created_datetime of this TemporaryFile.  # noqa: E501
        :rtype: str
        """
        return self._created_datetime

    @created_datetime.setter
    def created_datetime(self, created_datetime):
        """Sets the created_datetime of this TemporaryFile.

        Datetime when this temporary file was created.  # noqa: E501

        :param created_datetime: The created_datetime of this TemporaryFile.  # noqa: E501
        :type: str
        """

        self._created_datetime = created_datetime

    @property
    def eol_datetime(self):
        """Gets the eol_datetime of this TemporaryFile.  # noqa: E501

        Datetime when this temporary file may be deleted.  # noqa: E501

        :return: The eol_datetime of this TemporaryFile.  # noqa: E501
        :rtype: str
        """
        return self._eol_datetime

    @eol_datetime.setter
    def eol_datetime(self, eol_datetime):
        """Sets the eol_datetime of this TemporaryFile.

        Datetime when this temporary file may be deleted.  # noqa: E501

        :param eol_datetime: The eol_datetime of this TemporaryFile.  # noqa: E501
        :type: str
        """

        self._eol_datetime = eol_datetime

    @property
    def id(self):
        """Gets the id of this TemporaryFile.  # noqa: E501

        Unique integer identifying a temporary file.  # noqa: E501

        :return: The id of this TemporaryFile.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TemporaryFile.

        Unique integer identifying a temporary file.  # noqa: E501

        :param id: The id of this TemporaryFile.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def lookup(self):
        """Gets the lookup of this TemporaryFile.  # noqa: E501

        md5hash of lookup parameters  # noqa: E501

        :return: The lookup of this TemporaryFile.  # noqa: E501
        :rtype: str
        """
        return self._lookup

    @lookup.setter
    def lookup(self, lookup):
        """Sets the lookup of this TemporaryFile.

        md5hash of lookup parameters  # noqa: E501

        :param lookup: The lookup of this TemporaryFile.  # noqa: E501
        :type: str
        """

        self._lookup = lookup

    @property
    def name(self):
        """Gets the name of this TemporaryFile.  # noqa: E501

        Unique name for the temporary file  # noqa: E501

        :return: The name of this TemporaryFile.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TemporaryFile.

        Unique name for the temporary file  # noqa: E501

        :param name: The name of this TemporaryFile.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def path(self):
        """Gets the path of this TemporaryFile.  # noqa: E501

        Full URL to the temporary file.  # noqa: E501

        :return: The path of this TemporaryFile.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this TemporaryFile.

        Full URL to the temporary file.  # noqa: E501

        :param path: The path of this TemporaryFile.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def project(self):
        """Gets the project of this TemporaryFile.  # noqa: E501

        Unique integer identifying a project.  # noqa: E501

        :return: The project of this TemporaryFile.  # noqa: E501
        :rtype: int
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this TemporaryFile.

        Unique integer identifying a project.  # noqa: E501

        :param project: The project of this TemporaryFile.  # noqa: E501
        :type: int
        """

        self._project = project

    @property
    def user(self):
        """Gets the user of this TemporaryFile.  # noqa: E501

        Unique integer identifying user who created this file.  # noqa: E501

        :return: The user of this TemporaryFile.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this TemporaryFile.

        Unique integer identifying user who created this file.  # noqa: E501

        :param user: The user of this TemporaryFile.  # noqa: E501
        :type: int
        """

        self._user = user

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TemporaryFile, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TemporaryFile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class LocalizationUpdate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'attributes': 'dict(str, AttributeValue)',
        'frame': 'int',
        'height': 'float',
        'modified': 'bool',
        'parent': 'float',
        'u': 'float',
        'v': 'float',
        'width': 'float',
        'x': 'float',
        'y': 'float'
    }

    attribute_map = {
        'attributes': 'attributes',
        'frame': 'frame',
        'height': 'height',
        'modified': 'modified',
        'parent': 'parent',
        'u': 'u',
        'v': 'v',
        'width': 'width',
        'x': 'x',
        'y': 'y'
    }

    def __init__(self, attributes=None, frame=0, height=None, modified=None, parent=None, u=None, v=None, width=None, x=None, y=None):  # noqa: E501
        """LocalizationUpdate - a model defined in Swagger"""  # noqa: E501
        self._attributes = None
        self._frame = None
        self._height = None
        self._modified = None
        self._parent = None
        self._u = None
        self._v = None
        self._width = None
        self._x = None
        self._y = None
        self.discriminator = None
        if attributes is not None:
            self.attributes = attributes
        if frame is not None:
            self.frame = frame
        if height is not None:
            self.height = height
        if modified is not None:
            self.modified = modified
        if parent is not None:
            self.parent = parent
        if u is not None:
            self.u = u
        if v is not None:
            self.v = v
        if width is not None:
            self.width = width
        if x is not None:
            self.x = x
        if y is not None:
            self.y = y

    @property
    def attributes(self):
        """Gets the attributes of this LocalizationUpdate.  # noqa: E501

        Object containing attribute values.  # noqa: E501

        :return: The attributes of this LocalizationUpdate.  # noqa: E501
        :rtype: dict(str, AttributeValue)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this LocalizationUpdate.

        Object containing attribute values.  # noqa: E501

        :param attributes: The attributes of this LocalizationUpdate.  # noqa: E501
        :type: dict(str, AttributeValue)
        """

        self._attributes = attributes

    @property
    def frame(self):
        """Gets the frame of this LocalizationUpdate.  # noqa: E501

        Frame number of this localization if it is in a video.  # noqa: E501

        :return: The frame of this LocalizationUpdate.  # noqa: E501
        :rtype: int
        """
        return self._frame

    @frame.setter
    def frame(self, frame):
        """Sets the frame of this LocalizationUpdate.

        Frame number of this localization if it is in a video.  # noqa: E501

        :param frame: The frame of this LocalizationUpdate.  # noqa: E501
        :type: int
        """

        self._frame = frame

    @property
    def height(self):
        """Gets the height of this LocalizationUpdate.  # noqa: E501

        Normalized height of bounding box for `box` localization types.  # noqa: E501

        :return: The height of this LocalizationUpdate.  # noqa: E501
        :rtype: float
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this LocalizationUpdate.

        Normalized height of bounding box for `box` localization types.  # noqa: E501

        :param height: The height of this LocalizationUpdate.  # noqa: E501
        :type: float
        """

        self._height = height

    @property
    def modified(self):
        """Gets the modified of this LocalizationUpdate.  # noqa: E501

        Whether this localization was created in the web UI.  # noqa: E501

        :return: The modified of this LocalizationUpdate.  # noqa: E501
        :rtype: bool
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this LocalizationUpdate.

        Whether this localization was created in the web UI.  # noqa: E501

        :param modified: The modified of this LocalizationUpdate.  # noqa: E501
        :type: bool
        """

        self._modified = modified

    @property
    def parent(self):
        """Gets the parent of this LocalizationUpdate.  # noqa: E501

        If a clone, the pk of the parent.  # noqa: E501

        :return: The parent of this LocalizationUpdate.  # noqa: E501
        :rtype: float
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this LocalizationUpdate.

        If a clone, the pk of the parent.  # noqa: E501

        :param parent: The parent of this LocalizationUpdate.  # noqa: E501
        :type: float
        """

        self._parent = parent

    @property
    def u(self):
        """Gets the u of this LocalizationUpdate.  # noqa: E501

        Horizontal vector component for `line` localization types.  # noqa: E501

        :return: The u of this LocalizationUpdate.  # noqa: E501
        :rtype: float
        """
        return self._u

    @u.setter
    def u(self, u):
        """Sets the u of this LocalizationUpdate.

        Horizontal vector component for `line` localization types.  # noqa: E501

        :param u: The u of this LocalizationUpdate.  # noqa: E501
        :type: float
        """

        self._u = u

    @property
    def v(self):
        """Gets the v of this LocalizationUpdate.  # noqa: E501

        Vertical vector component for `line` localization types.  # noqa: E501

        :return: The v of this LocalizationUpdate.  # noqa: E501
        :rtype: float
        """
        return self._v

    @v.setter
    def v(self, v):
        """Sets the v of this LocalizationUpdate.

        Vertical vector component for `line` localization types.  # noqa: E501

        :param v: The v of this LocalizationUpdate.  # noqa: E501
        :type: float
        """

        self._v = v

    @property
    def width(self):
        """Gets the width of this LocalizationUpdate.  # noqa: E501

        Normalized width of bounding box for `box` localization types.  # noqa: E501

        :return: The width of this LocalizationUpdate.  # noqa: E501
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this LocalizationUpdate.

        Normalized width of bounding box for `box` localization types.  # noqa: E501

        :param width: The width of this LocalizationUpdate.  # noqa: E501
        :type: float
        """

        self._width = width

    @property
    def x(self):
        """Gets the x of this LocalizationUpdate.  # noqa: E501

        Normalized horizontal position of left edge of bounding box for `box` localization types, start of line for `line` localization types, or position of dot for `dot` localization types.  # noqa: E501

        :return: The x of this LocalizationUpdate.  # noqa: E501
        :rtype: float
        """
        return self._x

    @x.setter
    def x(self, x):
        """Sets the x of this LocalizationUpdate.

        Normalized horizontal position of left edge of bounding box for `box` localization types, start of line for `line` localization types, or position of dot for `dot` localization types.  # noqa: E501

        :param x: The x of this LocalizationUpdate.  # noqa: E501
        :type: float
        """

        self._x = x

    @property
    def y(self):
        """Gets the y of this LocalizationUpdate.  # noqa: E501

        Normalized vertical position of top edge of bounding box for `box` localization types, start of line for `line` localization types, or position of dot for `dot` localization types.  # noqa: E501

        :return: The y of this LocalizationUpdate.  # noqa: E501
        :rtype: float
        """
        return self._y

    @y.setter
    def y(self, y):
        """Sets the y of this LocalizationUpdate.

        Normalized vertical position of top edge of bounding box for `box` localization types, start of line for `line` localization types, or position of dot for `dot` localization types.  # noqa: E501

        :param y: The y of this LocalizationUpdate.  # noqa: E501
        :type: float
        """

        self._y = y

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LocalizationUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LocalizationUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Project(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'num_files': 'int',
        'permission': 'str',
        'size': 'int',
        'summary': 'str',
        'thumb': 'str',
        'usernames': 'list[str]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'num_files': 'num_files',
        'permission': 'permission',
        'size': 'size',
        'summary': 'summary',
        'thumb': 'thumb',
        'usernames': 'usernames'
    }

    def __init__(self, id=None, name=None, num_files=None, permission=None, size=None, summary='', thumb=None, usernames=None):  # noqa: E501
        """Project - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._num_files = None
        self._permission = None
        self._size = None
        self._summary = None
        self._thumb = None
        self._usernames = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if num_files is not None:
            self.num_files = num_files
        if permission is not None:
            self.permission = permission
        if size is not None:
            self.size = size
        if summary is not None:
            self.summary = summary
        if thumb is not None:
            self.thumb = thumb
        if usernames is not None:
            self.usernames = usernames

    @property
    def id(self):
        """Gets the id of this Project.  # noqa: E501

        Unique integer identifying the project.  # noqa: E501

        :return: The id of this Project.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Project.

        Unique integer identifying the project.  # noqa: E501

        :param id: The id of this Project.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Project.  # noqa: E501

        Name of the project.  # noqa: E501

        :return: The name of this Project.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Project.

        Name of the project.  # noqa: E501

        :param name: The name of this Project.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def num_files(self):
        """Gets the num_files of this Project.  # noqa: E501

        Number of files in the project.  # noqa: E501

        :return: The num_files of this Project.  # noqa: E501
        :rtype: int
        """
        return self._num_files

    @num_files.setter
    def num_files(self, num_files):
        """Sets the num_files of this Project.

        Number of files in the project.  # noqa: E501

        :param num_files: The num_files of this Project.  # noqa: E501
        :type: int
        """

        self._num_files = num_files

    @property
    def permission(self):
        """Gets the permission of this Project.  # noqa: E501

        Permission level of user making request.  # noqa: E501

        :return: The permission of this Project.  # noqa: E501
        :rtype: str
        """
        return self._permission

    @permission.setter
    def permission(self, permission):
        """Sets the permission of this Project.

        Permission level of user making request.  # noqa: E501

        :param permission: The permission of this Project.  # noqa: E501
        :type: str
        """

        self._permission = permission

    @property
    def size(self):
        """Gets the size of this Project.  # noqa: E501

        Size of the project in bytes.  # noqa: E501

        :return: The size of this Project.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this Project.

        Size of the project in bytes.  # noqa: E501

        :param size: The size of this Project.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def summary(self):
        """Gets the summary of this Project.  # noqa: E501

        Summary of the project.  # noqa: E501

        :return: The summary of this Project.  # noqa: E501
        :rtype: str
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """Sets the summary of this Project.

        Summary of the project.  # noqa: E501

        :param summary: The summary of this Project.  # noqa: E501
        :type: str
        """

        self._summary = summary

    @property
    def thumb(self):
        """Gets the thumb of this Project.  # noqa: E501

        URL of thumbnail used to represent the project.  # noqa: E501

        :return: The thumb of this Project.  # noqa: E501
        :rtype: str
        """
        return self._thumb

    @thumb.setter
    def thumb(self, thumb):
        """Sets the thumb of this Project.

        URL of thumbnail used to represent the project.  # noqa: E501

        :param thumb: The thumb of this Project.  # noqa: E501
        :type: str
        """

        self._thumb = thumb

    @property
    def usernames(self):
        """Gets the usernames of this Project.  # noqa: E501

        List of usernames of project members.  # noqa: E501

        :return: The usernames of this Project.  # noqa: E501
        :rtype: list[str]
        """
        return self._usernames

    @usernames.setter
    def usernames(self, usernames):
        """Sets the usernames of this Project.

        List of usernames of project members.  # noqa: E501

        :param usernames: The usernames of this Project.  # noqa: E501
        :type: list[str]
        """

        self._usernames = usernames

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Project, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Project):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AlgorithmLaunchSpec(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'algorithm_name': 'str',
        'media_ids': 'list[int]',
        'media_query': 'str'
    }

    attribute_map = {
        'algorithm_name': 'algorithm_name',
        'media_ids': 'media_ids',
        'media_query': 'media_query'
    }

    def __init__(self, algorithm_name=None, media_ids=None, media_query=None):  # noqa: E501
        """AlgorithmLaunchSpec - a model defined in Swagger"""  # noqa: E501
        self._algorithm_name = None
        self._media_ids = None
        self._media_query = None
        self.discriminator = None
        self.algorithm_name = algorithm_name
        if media_ids is not None:
            self.media_ids = media_ids
        if media_query is not None:
            self.media_query = media_query

    @property
    def algorithm_name(self):
        """Gets the algorithm_name of this AlgorithmLaunchSpec.  # noqa: E501

        Name of the algorithm to execute.  # noqa: E501

        :return: The algorithm_name of this AlgorithmLaunchSpec.  # noqa: E501
        :rtype: str
        """
        return self._algorithm_name

    @algorithm_name.setter
    def algorithm_name(self, algorithm_name):
        """Sets the algorithm_name of this AlgorithmLaunchSpec.

        Name of the algorithm to execute.  # noqa: E501

        :param algorithm_name: The algorithm_name of this AlgorithmLaunchSpec.  # noqa: E501
        :type: str
        """
        if algorithm_name is None:
            raise ValueError("Invalid value for `algorithm_name`, must not be `None`")  # noqa: E501

        self._algorithm_name = algorithm_name

    @property
    def media_ids(self):
        """Gets the media_ids of this AlgorithmLaunchSpec.  # noqa: E501

        List of media IDs. Must supply media_query or media_ids.  # noqa: E501

        :return: The media_ids of this AlgorithmLaunchSpec.  # noqa: E501
        :rtype: list[int]
        """
        return self._media_ids

    @media_ids.setter
    def media_ids(self, media_ids):
        """Sets the media_ids of this AlgorithmLaunchSpec.

        List of media IDs. Must supply media_query or media_ids.  # noqa: E501

        :param media_ids: The media_ids of this AlgorithmLaunchSpec.  # noqa: E501
        :type: list[int]
        """

        self._media_ids = media_ids

    @property
    def media_query(self):
        """Gets the media_query of this AlgorithmLaunchSpec.  # noqa: E501

        Query string used to filter media IDs. If supplied, media_ids will be ignored.  # noqa: E501

        :return: The media_query of this AlgorithmLaunchSpec.  # noqa: E501
        :rtype: str
        """
        return self._media_query

    @media_query.setter
    def media_query(self, media_query):
        """Sets the media_query of this AlgorithmLaunchSpec.

        Query string used to filter media IDs. If supplied, media_ids will be ignored.  # noqa: E501

        :param media_query: The media_query of this AlgorithmLaunchSpec.  # noqa: E501
        :type: str
        """

        self._media_query = media_query

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AlgorithmLaunchSpec, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AlgorithmLaunchSpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from tator.api.tator_api import TatorApi
# import ApiClient
from tator.api_client import ApiClient
from tator.configuration import Configuration
# import models into sdk package
from tator.models.algorithm import Algorithm
from tator.models.algorithm_launch import AlgorithmLaunch
from tator.models.algorithm_launch_spec import AlgorithmLaunchSpec
from tator.models.alpha_range import AlphaRange
from tator.models.analysis import Analysis
from tator.models.analysis_spec import AnalysisSpec
from tator.models.attribute_bulk_update import AttributeBulkUpdate
from tator.models.attribute_type import AttributeType
from tator.models.attribute_value import AttributeValue
from tator.models.autocomplete_service import AutocompleteService
from tator.models.bad_request_response import BadRequestResponse
from tator.models.color import Color
from tator.models.color_map import ColorMap
from tator.models.create_list_response import CreateListResponse
from tator.models.create_response import CreateResponse
from tator.models.credentials import Credentials
from tator.models.hex_color import HexColor
from tator.models.image_spec import ImageSpec
from tator.models.leaf import Leaf
from tator.models.leaf_spec import LeafSpec
from tator.models.leaf_suggestion import LeafSuggestion
from tator.models.leaf_type import LeafType
from tator.models.leaf_type_spec import LeafTypeSpec
from tator.models.leaf_type_update import LeafTypeUpdate
from tator.models.leaf_update import LeafUpdate
from tator.models.localization import Localization
from tator.models.localization_spec import LocalizationSpec
from tator.models.localization_type import LocalizationType
from tator.models.localization_type_spec import LocalizationTypeSpec
from tator.models.localization_type_update import LocalizationTypeUpdate
from tator.models.localization_update import LocalizationUpdate
from tator.models.media import Media
from tator.models.media_next import MediaNext
from tator.models.media_prev import MediaPrev
from tator.models.media_sections import MediaSections
from tator.models.media_type import MediaType
from tator.models.media_type_spec import MediaTypeSpec
from tator.models.media_type_update import MediaTypeUpdate
from tator.models.media_update import MediaUpdate
from tator.models.membership import Membership
from tator.models.membership_spec import MembershipSpec
from tator.models.membership_update import MembershipUpdate
from tator.models.message_response import MessageResponse
from tator.models.not_found_response import NotFoundResponse
from tator.models.notify_spec import NotifySpec
from tator.models.one_of_attribute_value import OneOfAttributeValue
from tator.models.one_of_color import OneOfColor
from tator.models.progress_spec import ProgressSpec
from tator.models.progress_summary_spec import ProgressSummarySpec
from tator.models.project import Project
from tator.models.project_spec import ProjectSpec
from tator.models.rgb_color import RgbColor
from tator.models.rgba_color import RgbaColor
from tator.models.section_analysis import SectionAnalysis
from tator.models.state import State
from tator.models.state_spec import StateSpec
from tator.models.state_type import StateType
from tator.models.state_type_spec import StateTypeSpec
from tator.models.state_type_update import StateTypeUpdate
from tator.models.state_update import StateUpdate
from tator.models.temporary_file import TemporaryFile
from tator.models.temporary_file_spec import TemporaryFileSpec
from tator.models.token import Token
from tator.models.transcode import Transcode
from tator.models.transcode_spec import TranscodeSpec
from tator.models.user import User
from tator.models.user_update import UserUpdate
from tator.models.version import Version
from tator.models.version_spec import VersionSpec
from tator.models.version_update import VersionUpdate
from tator.models.video_spec import VideoSpec
from tator.models.video_update import VideoUpdate



# coding: utf-8

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ColorMap(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'alpha_ranges': 'dict(str, AlphaRange)',
        'default': 'Color',
        'key': 'str',
        'map': 'dict(str, Color)',
        'version': 'dict(str, Color)'
    }

    attribute_map = {
        'alpha_ranges': 'alpha_ranges',
        'default': 'default',
        'key': 'key',
        'map': 'map',
        'version': 'version'
    }

    def __init__(self, alpha_ranges=None, default=None, key=None, map=None, version=None):  # noqa: E501
        """ColorMap - a model defined in Swagger"""  # noqa: E501
        self._alpha_ranges = None
        self._default = None
        self._key = None
        self._map = None
        self._version = None
        self.discriminator = None
        if alpha_ranges is not None:
            self.alpha_ranges = alpha_ranges
        if default is not None:
            self.default = default
        if key is not None:
            self.key = key
        if map is not None:
            self.map = map
        if version is not None:
            self.version = version

    @property
    def alpha_ranges(self):
        """Gets the alpha_ranges of this ColorMap.  # noqa: E501

        Map of attribute values to alpha level.  # noqa: E501

        :return: The alpha_ranges of this ColorMap.  # noqa: E501
        :rtype: dict(str, AlphaRange)
        """
        return self._alpha_ranges

    @alpha_ranges.setter
    def alpha_ranges(self, alpha_ranges):
        """Sets the alpha_ranges of this ColorMap.

        Map of attribute values to alpha level.  # noqa: E501

        :param alpha_ranges: The alpha_ranges of this ColorMap.  # noqa: E501
        :type: dict(str, AlphaRange)
        """

        self._alpha_ranges = alpha_ranges

    @property
    def default(self):
        """Gets the default of this ColorMap.  # noqa: E501


        :return: The default of this ColorMap.  # noqa: E501
        :rtype: Color
        """
        return self._default

    @default.setter
    def default(self, default):
        """Sets the default of this ColorMap.


        :param default: The default of this ColorMap.  # noqa: E501
        :type: Color
        """

        self._default = default

    @property
    def key(self):
        """Gets the key of this ColorMap.  # noqa: E501

        Attribute name.  # noqa: E501

        :return: The key of this ColorMap.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this ColorMap.

        Attribute name.  # noqa: E501

        :param key: The key of this ColorMap.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def map(self):
        """Gets the map of this ColorMap.  # noqa: E501

        Map of attribute values to colors.  # noqa: E501

        :return: The map of this ColorMap.  # noqa: E501
        :rtype: dict(str, Color)
        """
        return self._map

    @map.setter
    def map(self, map):
        """Sets the map of this ColorMap.

        Map of attribute values to colors.  # noqa: E501

        :param map: The map of this ColorMap.  # noqa: E501
        :type: dict(str, Color)
        """

        self._map = map

    @property
    def version(self):
        """Gets the version of this ColorMap.  # noqa: E501

        Map of version IDs to colors.  # noqa: E501

        :return: The version of this ColorMap.  # noqa: E501
        :rtype: dict(str, Color)
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ColorMap.

        Map of version IDs to colors.  # noqa: E501

        :param version: The version of this ColorMap.  # noqa: E501
        :type: dict(str, Color)
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ColorMap, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ColorMap):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
